@@ -17,7 +17,7 @@ test_that("x and y can be numeric vectors", {
   expect_equal(row_oneway_welch(x=x, g=grp), row_oneway_welch(x=X, g=grp))
   expect_equal(row_kruskalwallis(x=x, g=grp), row_kruskalwallis(x=X, g=grp))
   expect_equal(row_bartlett(x=x, g=grp), row_bartlett(x=X, g=grp))
-  expect_equal(row_ievora(x=x, g=grp), row_ievora(x=X, g=grp))
+  expect_equal(row_ievora(x=x, b=grp), row_ievora(x=X, b=grp))
 })
 
 test_that("x and y can be numeric data.frames", {
@@ -33,7 +33,7 @@ test_that("x and y can be numeric data.frames", {
   expect_equal(row_oneway_welch(x=x, g=grp), row_oneway_welch(x=X, g=grp))
   expect_equal(row_kruskalwallis(x=x, g=grp), row_kruskalwallis(x=X, g=grp))
   expect_equal(row_bartlett(x=x, g=grp), row_bartlett(x=X, g=grp))
-  expect_equal(row_ievora(x=x, g=grp), row_ievora(x=X, g=grp))
+  expect_equal(row_ievora(x=x, b=grp), row_ievora(x=X, b=grp))
 })
 
 test_that("x and y can have 0 rows and 0 columns", {
@@ -49,7 +49,7 @@ test_that("x and y can have 0 rows and 0 columns", {
   expect_equal(nrow(row_oneway_welch(x=x, g=grp)), 0)
   expect_equal(nrow(row_kruskalwallis(x=x, g=grp)), 0)
   expect_equal(nrow(row_bartlett(x=x, g=grp)), 0)
-  expect_equal(nrow(row_ievora(x=x, g=grp)), 0)
+  expect_equal(nrow(row_ievora(x=x, b=grp)), 0)
 })
 
 test_that("NA and NaN are treated the same", {
@@ -69,7 +69,7 @@ test_that("NA and NaN are treated the same", {
   expect_equal(row_oneway_welch(x=Xna, g=grp), row_oneway_welch(x=Xnan, g=grp))
   expect_equal(row_kruskalwallis(x=Xna, g=grp), row_kruskalwallis(x=Xnan, g=grp))
   expect_equal(row_bartlett(x=Xna, g=grp), row_bartlett(x=Xnan, g=grp))
-  expect_equal(row_ievora(x=Xna, g=grp), row_ievora(x=Xnan, g=grp))
+  expect_equal(row_ievora(x=Xna, b=grp), row_ievora(x=Xnan, b=grp))
 })
 
 ################################################################################
@@ -93,8 +93,8 @@ test_that("NA and NaN produce the same result", {
   expect_equal(suppressWarnings(row_kruskalwallis(x=x, g=grp1)), suppressWarnings(row_kruskalwallis(x=x, g=grp3)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp1)), suppressWarnings(row_bartlett(x=x, g=grp2)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp1)), suppressWarnings(row_bartlett(x=x, g=grp3)))
-  expect_equal(suppressWarnings(row_ievora(x=x, g=grp1)), suppressWarnings(row_ievora(x=x, g=grp2)))
-  expect_equal(suppressWarnings(row_ievora(x=x, g=grp1)), suppressWarnings(row_ievora(x=x, g=grp3)))
+  expect_equal(suppressWarnings(row_ievora(x=x, b=grp1)), suppressWarnings(row_ievora(x=x, b=grp2)))
+  expect_equal(suppressWarnings(row_ievora(x=x, b=grp1)), suppressWarnings(row_ievora(x=x, b=grp3)))
 })
 
 test_that("groups can all be NA", {
@@ -104,7 +104,7 @@ test_that("groups can all be NA", {
   expect_equal(suppressWarnings(row_oneway_welch(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_kruskalwallis(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
-  expect_equal(suppressWarnings(row_ievora(x=x, g=grp)$obs.0), rep(0, nrow(x)))
+  expect_equal(suppressWarnings(row_ievora(x=x, b=grp)$obs.0), rep(0, nrow(x)))
 })
 
 test_that("groups can all be NaN", {
@@ -114,7 +114,7 @@ test_that("groups can all be NaN", {
   expect_equal(suppressWarnings(row_oneway_welch(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_kruskalwallis(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp)$obs.tot), rep(0, nrow(x)))
-  expect_equal(suppressWarnings(row_ievora(x=x, g=grp)$obs.0), rep(0, nrow(x)))
+  expect_equal(suppressWarnings(row_ievora(x=x, b=grp)$obs.0), rep(0, nrow(x)))
 })
 
 test_that("all observations can be in the same group", {
@@ -124,7 +124,7 @@ test_that("all observations can be in the same group", {
   expect_equal(suppressWarnings(row_oneway_welch(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
   expect_equal(suppressWarnings(row_kruskalwallis(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
   expect_equal(suppressWarnings(row_bartlett(x=x, g=grp)$obs.groups), rep(1, nrow(x)))
-  expect_equal(suppressWarnings(row_ievora(x=x, g=grp)$obs.0), rep(ncol(x), nrow(x)))
+  expect_equal(suppressWarnings(row_ievora(x=x, b=grp)$obs.0), rep(ncol(x), nrow(x)))
 })
 
 
@@ -136,7 +136,7 @@ test_that("groups can be character", {
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
-  expect_equal(row_ievora(x=x, g=grp1), row_ievora(x=x, g=grp2))
+  expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
 })
 
 test_that("groups can be factor", {
@@ -147,7 +147,7 @@ test_that("groups can be factor", {
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
-  expect_equal(row_ievora(x=x, g=grp1), row_ievora(x=x, g=grp2))
+  expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
 })
 
 test_that("groups can be logical", {
@@ -158,7 +158,7 @@ test_that("groups can be logical", {
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
-  expect_equal(row_ievora(x=x, g=grp1), row_ievora(x=x, g=grp2))
+  expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
 })
 
 test_that("groups can be complex", {
@@ -169,7 +169,7 @@ test_that("groups can be complex", {
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
-  expect_equal(row_ievora(x=x, g=grp1), row_ievora(x=x, g=grp2))
+  expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
 })
 
 test_that("groups can be a list", {
@@ -180,7 +180,7 @@ test_that("groups can be a list", {
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
-  expect_equal(row_ievora(x=x, g=grp1), row_ievora(x=x, g=grp2))
+  expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
 })
 
 test_that("groups can be a matrix", {
@@ -191,7 +191,7 @@ test_that("groups can be a matrix", {
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
-  expect_equal(row_ievora(x=x, g=grp1), row_ievora(x=x, g=grp2))
+  expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
 })
 
 test_that("groups can be infinite", {
@@ -202,7 +202,7 @@ test_that("groups can be infinite", {
   expect_equal(row_oneway_welch(x=x, g=grp1), row_oneway_welch(x=x, g=grp2))
   expect_equal(row_kruskalwallis(x=x, g=grp1), row_kruskalwallis(x=x, g=grp2))
   expect_equal(row_bartlett(x=x, g=grp1), row_bartlett(x=x, g=grp2))
-  expect_equal(row_ievora(x=x, g=grp1), row_ievora(x=x, g=grp2))
+  expect_equal(row_ievora(x=x, b=grp1), row_ievora(x=x, b=grp2))
 })
 
 ################################################################################
